#!/usr/bin/env node

var config = require('../config');
var GeneratePackage = require('../lib/GeneratePackage/index');
var ExecuteNPMScripts = require('../lib/ExecuteNPMScripts/index');
var DeployLambdaCode = require('../lib/DeployLambdaCode/index');
var DeployCFStack = require('../lib/DeployCFStack/index');
var _ = require('lodash');
var async = require('async');

console.log("CONFIG: ", config);

async.auto({
    GeneratePackage: function (next) {
        console.log("ROOT PATH: ", config.ROOT_PATH);
        GeneratePackage(config.ROOT_PATH, next);
    },
    ExecuteNPMScripts: ['GeneratePackage', function (result, next) {
        ExecuteNPMScripts(result.GeneratePackage.scripts, next);
    }],
    Deploy: ['GeneratePackage', 'ExecuteNPMScripts', function (result, next) {
        console.log("CURRENT BRANCH: ", config.GIT_BRANCH);
        var branchIndex = _.findIndex(config.DEPLOY_BRANCHES, function (b) {
            return b == config.GIT_BRANCH;
        });
    
        if(branchIndex == -1)
            return next(null, {message: "Branch isn't in the valid branches", stage: 'InvalidBranch'});

    
        var branch = config.NAME_BRANCHES[branchIndex];
        if(!branch)
            return next(null, {message: "Branch isn't in the valid branches names", stage: 'InvalidBranchName'});

        async.series([
            function (cb) {
                DeployLambdaCode(config.LAMBDA_PATH, branch, result.GeneratePackage.directories, cb);
            },
            function (cb) {
                DeployCFStack(config.CF_PATH, branch, cb);
            }
        ], next);
    }]
}, function (err, result) {
    if(err)
        throw err;
});