var fs = require('fs');
var path = require('path');
var config = require('./config');
var async = require('async');
var _ = require('lodash');
var EXCLUDE_FOLDER = require('../../config').EXCLUDE_FOLDER;
var directories = {};
var scripts = {};


//Check if there is a package.json in the current directory and call an async.each for check every subdirectory
function getDirectories(dirname, lastFolderName, done) {
    fs.readdir(dirname, function (err, dirs) {
        if(err)
            return done({code: 'ReadDirectory', details: err});
        
        //End if is an empty folder
        if(dirs && dirs.length == 0){
            return done();
        }
        
        var hasPackage = dirs.findIndex(function (d) {
                return d == 'package.json';
            }) != -1;
        
        //Add package to scripts
        if(hasPackage && lastFolderName){
            scripts[lastFolderName] = config.scriptCommand.replace('{directory}', dirname);
            directories[lastFolderName] = dirname;
        }
        
        async.each(dirs, iteratee(dirname), function (err) {
            done(err);
        });
    });
}

//Check if the current dirname is a directory to check for new package.json
var iteratee = function (dirname) {
    return function (d, cb) {
        var p = path.join(dirname, d);
        var stat = fs.statSync(p);
        if(stat.isDirectory() && !excludeFolder(d)) {
            return getDirectories(p, d, cb);
        }
        
        cb();
    }
};

//Function to find package.json recursively from root and write a new package.json file
module.exports = function (root, done) {
    getDirectories(root, null, function (err) {
        if (err)
            return done(err);
    
        var packagePath = path.join(root, 'package.json');
        var rootPkg = require(packagePath);
        _.assign(rootPkg.scripts, scripts);
        
        fs.appendFile(packagePath, JSON.stringify(rootPkg), {flag: 'w'}, function (err, res) {
            if (err)
                return done({code: 'AppendFile', details: err});
            
            done(null, {message: 'Package successfully created', scripts: scripts, directories: directories});
        });
    });
};


function excludeFolder(d) {
    EXCLUDE_FOLDER = EXCLUDE_FOLDER.concat(['node_modules', '.git', '.idea']);
    return index = _.findIndex(EXCLUDE_FOLDER, function (folderName) {
        return folderName == d;
    }) != -1
}