var sinon = require('sinon');
var expect = require('chai').expect;
var path = require('path');
var fs = require('fs');
var aws = require('aws-sdk');
var config = require('../../config');
var DeployCFStack = require('../../lib/DeployCFStack/index');
var UploadS3 = require('../../lib/UploadS3/index');
var _ = require('lodash');


describe('Deploy CF Stack', function () {
    var stubAwsSdk = null;
    var returnsS3 = {
        upload: function () {
            return this;
        },
        send: function (cb) {
            cb();
        }
    };
    
    beforeEach(function (done) {
        stubAwsSdk = sinon.stub(aws, 'S3').returns(returnsS3);
        done();
    });
    
    afterEach(function (done) {
        stubAwsSdk.restore();
        done();
    });
    
    it('Upload 2 cf stack', function (done) {
        var provisioningPath = path.resolve(__dirname, '../example/provisioning');
        var currentBranch = 'development';
        DeployCFStack(provisioningPath, currentBranch, function (err, result) {
            expect(err).to.not.exist;
            expect(result).to.exist;
            expect(result).to.have.lengthOf(2);
            done();
        });
    });
    
    it('Does not upload file with invalid extension', function (done) {
        var provisioningPath = path.resolve(__dirname, '../example/provisioning');
        var currentBranch = 'development';
        var stub = sinon.stub(fs, 'readdir').yields(null, ['file.txt']);
        DeployCFStack(provisioningPath, currentBranch, function (err, result) {
            stub.restore();
            expect(err).to.not.exist;
            expect(result).to.exist;
            expect(result).to.have.lengthOf(1);
            expect(result[0].stage).to.equal('InvalidExt');
            done();
        });
    });
    
    it('Get error at readdir', function (done) {
        var provisioningPath = path.resolve(__dirname, '../example/provisioning');
        var currentBranch = 'development';
        var stub = sinon.stub(fs, 'readdir').yields(new Error('Oops'));
        DeployCFStack(provisioningPath, currentBranch, function (err, result) {
            stub.restore();
            expect(err).to.exist;
            expect(result).to.not.exist;
            expect(err.code).to.equal('ReadDirectory');
            done();
        });
    });
});