var sinon = require('sinon');
var expect = require('chai').expect;
var path = require('path');
var aws = require('aws-sdk');
var config = require('../../config');
var DeployLambdaCode = require('../../lib/DeployLambdaCode/index');
var UploadS3 = require('../../lib/UploadS3/index');
var _ = require('lodash');


describe('Deploy Lambda Code', function () {
    var stubAwsSdk = null;
    var returnsS3 = {
        upload: function () {
            return this;
        },
        send: function (cb) {
            cb();
        }
    };
    
    beforeEach(function (done) {
        stubAwsSdk = sinon.stub(aws, 'S3').returns(returnsS3);
        done();
    });
    
    afterEach(function (done) {
        stubAwsSdk.restore();
        done();
    });
    
    it('Execute script', function (done) {
        var lambdaPath = path.resolve(__dirname, '../example/lambda');
        var currentBranch = 'development';
        var directories = {
            d1: path.resolve(__dirname, '../example/lambda/d1'),
            d2_2: path.resolve(__dirname, '../example/lambda/d2/d2_1')
        };
        DeployLambdaCode(lambdaPath, currentBranch, directories, function (err, result) {
            expect(err).to.not.exist;
            expect(result).to.exist;
            expect(result.d1).to.exist;
            expect(result.d2_2).to.exist;
    
            expect(result.d1).to.have.all.keys(['generateZip', 'uploadFile', 'removeZip']);
            expect(result.d2_2).to.have.all.keys(['generateZip', 'uploadFile', 'removeZip']);
            done();
        });
    });
});