var sinon = require('sinon');
var expect = require('chai').expect;
var path = require('path');
var config = require('../../config');
var child_process = require('child_process');
var ExecuteNPMScripts = require('../../lib/ExecuteNPMScripts/index');
var _ = require('lodash');

describe('Execute NPM Scripts', function () {
    
    it('Execute 2 scripts', function (done) {
        var paramsExec = [];
        var stub = sinon.stub(child_process, 'exec', function (input, cb) {
            paramsExec.push(input);
            cb()
        });
        ExecuteNPMScripts({user: 'test', pkg: 'test'}, function (err, result) {
            stub.restore();
            expect(err).to.not.exist;
            expect(paramsExec).to.have.lengthOf(2);
            expect(paramsExec[0]).to.equal("npm run-script user");
            expect(paramsExec[1]).to.equal("npm run-script pkg");
            done();
        });
    });
    
    it('Execute with empty scripts', function (done) {
        var paramsExec = [];
        var stub = sinon.stub(child_process, 'exec', function (input, cb) {
            paramsExec.push(input);
            cb()
        });
        ExecuteNPMScripts({}, function (err, result) {
            stub.restore();
            expect(err).to.not.exist;
            expect(paramsExec).to.be.empty;
            done();
        });
    });
    
    it('Get error at execute script', function (done) {
        var paramsExec = [];
        var stub = sinon.stub(child_process, 'exec', function (input, cb) {
            paramsExec.push(input);
            cb(new Error('Oops'))
        });
        ExecuteNPMScripts({user: 'test'}, function (err, result) {
            stub.restore();
            expect(err).to.exist;
            expect(err).to.have.lengthOf(1)
            done();
        });
    });
    
});