var sinon = require('sinon');
var expect = require('chai').expect;
var path = require('path');
var config = require('../../config');
var fs = require('fs');
var GeneratePackage = require('../../lib/GeneratePackage/index');
var _ = require('lodash');

describe('Generate Package', function () {
    var stubFS = null;
    
    beforeEach(function (done) {
        stubFS = sinon.stub(fs, 'appendFile').yields();
        done();
    });
    
    afterEach(function (done) {
        stubFS.restore();
        done();
    });
    
    it('Generate pkg successfully', function (done) {
        var dir = path.resolve(__dirname, '../example');
        GeneratePackage(dir, function (err, result) {
            expect(err).to.not.exist;
            expect(result).to.exist;
            expect(result.message).to.exist;
            expect(result.scripts).to.have.all.keys(['d1', 'd2_1']);
            expect(result.directories.d1).to.equal(path.resolve(dir, 'lambda/d1'));
            expect(result.directories.d2_1).to.equal(path.resolve(dir, 'lambda/d2/d2_1'));
            done();
        });
    });
    
    it('Get error at append file', function (done) {
        var dir = path.resolve(__dirname, '../example');
        stubFS.yields(new Error('Oops'));
        GeneratePackage(dir, function (err, result) {
            expect(err).to.exist;
            expect(err.code).to.equal('AppendFile');
            expect(result).to.not.exist;
            done();
        });
    });
    
    it('Get error at get dirs', function (done) {
        var dir = path.resolve(__dirname, '../example');
        var stub = sinon.stub(fs, 'readdir').yields(new Error('Oops'));
        GeneratePackage(dir, function (err, result) {
            stub.restore();
            expect(err).to.exist;
            expect(err.code).to.equal('ReadDirectory');
            expect(result).to.not.exist;
            done();
        });
    });
});