var sinon = require('sinon');
var expect = require('chai').expect;
var path = require('path');
var aws = require('aws-sdk');
var config = require('../../config');
var s3Handler = require('../../lib/UploadS3/s3Handler');
var _ = require('lodash');


describe('Upload S3 - s3Handler', function () {
    var stubAwsSdk = null;
    var returnsS3 = {
        upload: function () {
            return this;
        },
        send: function (cb) {
            cb();
        }
    };
    
    beforeEach(function (done) {
        stubAwsSdk = sinon.stub(aws, 'S3').returns(returnsS3);
        done();
    });
    
    afterEach(function (done) {
        stubAwsSdk.restore();
        done();
    });
    
    it('Upload file to S3', function (done) {
        var filePath = path.resolve(__dirname, '../example/file.txt');
        var s3Path = 'example/file.txt';
        var bucket = "bucket";
        
        s3Handler.uploadFile(filePath, s3Path, bucket, function (err, result) {
            expect(err).to.not.exist;
            expect(result).to.exist;
            expect(result).to.have.all.keys(['filePath', 'detail']);
            
            done()
        });
    });
    
    it('Get error if file not exist', function (done) {
        var filePath = path.resolve(__dirname, '/file.txt');
        var s3Path = 'example/file.txt';
        var bucket = "bucket";
    
        s3Handler.uploadFile(filePath, s3Path, bucket, function (err, result) {
            expect(err).to.exist;
            expect(err.code).to.equal('CatchError');
            expect(result).to.not.exist;
            done()
        });
    });
    
    it('Get error if cant upload to s3', function (done) {
        var filePath = path.resolve(__dirname, '../example/file.txt');
        var s3Path = 'example/file.txt';
        var bucket = "bucket";
    
        stubAwsSdk.returns({
            upload: function () {
                return this;
            },
            send: function (cb) {
                cb(new Error('Oops'));
            }
        });
    
        s3Handler.uploadFile(filePath, s3Path, bucket, function (err, result) {
            expect(err).to.exist;
            expect(err.code).to.equal('UploadFileS3');
            expect(result).to.not.exist;
            done()
        });
    });
});